@@ -2,7 +2,7 @@
 use crate::internal_prelude::*;
 use crate::{
 	config, hyper_utils, load_filters,
-	parser_processor::ParserProcessor,
+	parser_processor::{Handle, ParserProcessor},
 	resolver::{Adaptor, AsyncHyperResolver, Resolver},
 	status_filters, task_expanders, task_filters,
 	task_processor::*,
@@ -210,7 +210,7 @@ impl<R: Resolver> ClientFactory<R> for HttpClientFactory<R> {
 
 pub struct Crawler<R: Resolver = AsyncHyperResolver> {
 	networking_profile: config::ResolvedNetworkingProfile<R>,
-	pp:                 ParserProcessor,
+	parse_tx:           Sender<ParserTask>,
 }
 
 pub struct CrawlerIter<JS: JobStateValues, TS: TaskStateValues> {
@@ -235,16 +235,20 @@ impl<JS: JobStateValues, TS: TaskStateValues> CrawlerIter<JS, TS> {
 impl Crawler<AsyncHyperResolver> {
 	pub fn new_default() -> anyhow::Result<Crawler<AsyncHyperResolver>> {
 		let concurrency_profile = config::ConcurrencyProfile::default();
-		let pp = ParserProcessor::new(concurrency_profile, 1024 * 1024 * 32);
+		let pp = ParserProcessor::spawn(concurrency_profile, 1024 * 1024 * 32);
 
 		let networking_profile = config::NetworkingProfile::default().resolve()?;
-		Ok(Crawler::new(networking_profile, pp))
+		Ok(Crawler::new(networking_profile, &pp))
 	}
 }
 
 impl<R: Resolver> Crawler<R> {
-	pub fn new(networking_profile: config::ResolvedNetworkingProfile<R>, pp: ParserProcessor) -> Crawler<R> {
-		Crawler { networking_profile, pp }
+	pub fn new(networking_profile: config::ResolvedNetworkingProfile<R>, pp: &Handle) -> Crawler<R> {
+		Self::_new(networking_profile, pp.tx.clone())
+	}
+
+	pub fn _new(networking_profile: config::ResolvedNetworkingProfile<R>, parse_tx: Sender<ParserTask>) -> Crawler<R> {
+		Crawler { networking_profile, parse_tx }
 	}
 
 	pub fn iter<JS: JobStateValues, TS: TaskStateValues>(self, job: Job<JS, TS>) -> CrawlerIter<JS, TS> {
@@ -272,11 +276,11 @@ impl<R: Resolver> Crawler<R> {
 
 			let mut processor_handles = vec![];
 			for i in 0..job.settings.concurrency {
-				let mut processor = TaskProcessor::new(
+				let processor = TaskProcessor::new(
 					job.clone(),
 					scheduler.job_update_tx.clone(),
 					scheduler.tasks_rx.clone(),
-					self.pp.clone(),
+					self.parse_tx.clone(),
 					Box::new(client_factory.clone()),
 					Arc::clone(&self.networking_profile.resolver),
 					true,
@@ -302,9 +306,9 @@ impl<R: Resolver> Crawler<R> {
 
 #[derive(Clone)]
 pub struct MultiCrawler<JS: JobStateValues, TS: TaskStateValues, R: Resolver> {
-	pp:                  ParserProcessor,
 	job_rx:              Receiver<Job<JS, TS>>,
 	update_tx:           Sender<JobUpdate<JS, TS>>,
+	parse_tx:            Sender<ParserTask>,
 	concurrency_profile: config::ConcurrencyProfile,
 	networking_profile:  config::ResolvedNetworkingProfile<R>,
 }
@@ -312,18 +316,22 @@ pub struct MultiCrawler<JS: JobStateValues, TS: TaskStateValues, R: Resolver> {
 pub type MultiCrawlerTuple<JS, TS, R> = (MultiCrawler<JS, TS, R>, Sender<Job<JS, TS>>, Receiver<JobUpdate<JS, TS>>);
 impl<JS: JobStateValues, TS: TaskStateValues, R: Resolver> MultiCrawler<JS, TS, R> {
 	pub fn new(
-		pp: ParserProcessor,
+		pp_h: &Handle,
 		concurrency_profile: config::ConcurrencyProfile,
 		networking_profile: config::ResolvedNetworkingProfile<R>,
 	) -> MultiCrawlerTuple<JS, TS, R> {
 		let (job_tx, job_rx) = bounded_ch::<Job<JS, TS>>(concurrency_profile.job_tx_buffer_size());
 		let (update_tx, update_rx) = bounded_ch::<JobUpdate<JS, TS>>(concurrency_profile.job_update_buffer_size());
-		(MultiCrawler { job_rx, update_tx, pp, concurrency_profile, networking_profile }, job_tx, update_rx)
+		(
+			MultiCrawler { job_rx, update_tx, parse_tx: pp_h.tx.clone(), concurrency_profile, networking_profile },
+			job_tx,
+			update_rx,
+		)
 	}
 
 	async fn process(self) -> Result<()> {
 		while let Ok(job) = self.job_rx.recv_async().await {
-			let crawler = Crawler::new(self.networking_profile.clone(), self.pp.clone());
+			let crawler = Crawler::_new(self.networking_profile.clone(), self.parse_tx.clone());
 			let _ = crawler.go(job, self.update_tx.clone()).await;
 		}
 		Ok(())
